@@ -26,12 +26,12 @@ mtx_lv1_en = None
 mtx_lv3_concat_en = None
 
 POSTAL_CODE_EXP = "((\d{5})(?:$|[ ,]+.+$))"
-PLUS_CODE_EXP = "(?:^|,|^.+ )([A-Z\d]+\+[A-Z\d]+)[ ,]+"
-HOUSE_NO_EXP1 = "((?:^|,|^.+ )((\d{1,3})/\d{1,3}-\d{1,3}/\d{1,3})[ ,]+)\w"
-HOUSE_NO_EXP2 = "((?:^|,|^.+ )((\d{1,3})/\d{1,3}-\d{1,3})[ ,]+)\w"
-HOUSE_NO_EXP3 = "((?:^|,|^.+ )(\d{1,3}-\d{1,3}/(\d{1,3}))[ ,]+)\w"
-HOUSE_NO_EXP4 = "((?:^|,|^.+ )((\d{1,3})[/ ]\d{1,3})[ ,]+)\w"
-HOUSE_NO_EXP5 = "((?:^|,|^.+ )(?:No(?:\.|\. | ))?(\d{1,4})[ ,]+)\w"
+PLUS_CODE_EXP = "(?:^|,|^[^0-9]+ )([A-Z\d]+\+[A-Z\d]+)[ ,]+"
+HOUSE_NO_EXP1 = "((?:^|,|^[^0-9]+ )((\d{1,3})/\d{1,3}-\d{1,3}/\d{1,3})[ ,]+)\w"
+HOUSE_NO_EXP2 = "((?:^|,|^[^0-9]+ )((\d{1,3})/\d{1,3}-\d{1,3})[ ,]+)\w"
+HOUSE_NO_EXP3 = "((?:^|,|^[^0-9]+ )(\d{1,3}-\d{1,3}/(\d{1,3}))[ ,]+)\w"
+HOUSE_NO_EXP4 = "((?:^|,|^[^0-9]+ )((\d{1,3})[/ ]\d{1,3})[ ,]+)\w"
+HOUSE_NO_EXP5 = "((?:^|,|^[^0-9]+ )(?:No(?:\.|\. | ))?(\d{1,4})[ ,]+)\w"
 VILLAGE_EXP = "(?i)(?:^|,| )(?:หมู่ที่|หมู่ที่|หมู่|ม .|ม.|Moo|Mu)\s?(\d+)"
 ROAD_EXP1 = "(?i)(?:^|,| )(?:(Soi [A-Za-z\- ]+(?: \d{1,4})?)|((?:ซอย|ถนน) [^ ]+(?: \d{1,4})?)|((?:ถ |ถ|ชบ)\.[^ ]+(?: \d{1,4})?))(?: |,|$)"
 ROAD_EXP2 = "(?i)(?:^|(?:[^A-Za-z\-\. ]))([A-Za-z\-\. ]+ (?:\d{1,4} )?(?:Soi|Road|Raod|Rd\.?|Highway|Route|Alley|Avenue|Ave\.?|Street|St\.?|Drive|Dr\.?|Central|Circuit|Close|Crescent|Circle|Way|Lane|Ln\.?|Link|Loop|Sector|Walk|Industrial Estate|Industry Estate|Estate|Industrial Park|Industry Park|Park)(?: \d{1,4})?)(?: |,|$)"
@@ -134,7 +134,7 @@ def extract_street_name(text):
 
 
 def extract_house_no(text):
-    substr = text[:30]
+    substr = text[:40]
 
     match = re.search(HOUSE_NO_EXP1, substr)
     if match is not None:
@@ -609,6 +609,7 @@ def match_thai_vendor_addresses(customer_address, vendor_addresses, text_dist_th
 
             pinpoint_sim = np.zeros(len(vendor_addresses))
             for i, vendor_addr in enumerate(vendor_addresses):
+                # i, vendor_addr = 0, vendor_addresses[0]
                 if type(vendor_addr) == str:
                     vendor_addr_text_upper = "" if vendor_addr is None else vendor_addr.upper()
                 elif type(vendor_addr) == dict:
@@ -624,6 +625,7 @@ def match_thai_vendor_addresses(customer_address, vendor_addresses, text_dist_th
         else:
             pinpoint_sim = np.zeros(len(vendor_addresses))
             for i, vendor_addr in enumerate(vendor_addresses):
+                # i, vendor_addr = 0, vendor_addresses[0]
                 if type(vendor_addr) == str:
                     vendor_addr_text_upper = "" if vendor_addr is None else vendor_addr.upper()
                 elif type(vendor_addr) == dict:
@@ -642,6 +644,7 @@ def match_thai_vendor_addresses(customer_address, vendor_addresses, text_dist_th
 
         admin_area_matched = np.zeros(len(vendor_addresses), dtype=bool)
         for i, vendor_addr in enumerate(vendor_addresses):
+            # i, vendor_addr = 0, vendor_addresses[0]
             if type(vendor_addr) == str:
                 vendor_addr_text_upper = "" if vendor_addr is None else vendor_addr.upper()
             elif type(vendor_addr) == dict:
@@ -662,9 +665,9 @@ def match_thai_vendor_addresses(customer_address, vendor_addresses, text_dist_th
                     pinpoint_sim[i] = 0
             elif (cust_comp["admin_lv3"] is not None) and (vendor_comp["admin_lv3"] == cust_comp["admin_lv3"]):
                 admin_area_matched[i] = True
-            elif (cust_comp["admin_lv2"] is not None) and (vendor_comp["admin_lv2"] == cust_comp["admin_lv2"]):
+            elif (cust_comp["admin_lv2"] is not None) and (vendor_comp["admin_lv2"] == cust_comp["admin_lv2"]) and ((vendor_comp["admin_lv3"] is None) or (cust_comp["admin_lv3"] is None)):
                 admin_area_matched[i] = True
-            elif (cust_comp["admin_lv1"] is not None) and (vendor_comp["admin_lv1"] == cust_comp["admin_lv1"]):
+            elif (cust_comp["admin_lv1"] is not None) and (vendor_comp["admin_lv1"] == cust_comp["admin_lv1"]) and ((vendor_comp["admin_lv2"] is None) or (cust_comp["admin_lv2"] is None)):
                 admin_area_matched[i] = True
 
         if np.any(pinpoint_sim > text_dist_thresh):
